%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% This is a class for LaTeX2e that should format a report as per
% the Department of Electronics Engineering, SGU Kolhapur Thesis guidelines.  The page layout is set using the
% geometry package.  The double/singlespacing is setup using
% setspace.  Figure captions are set using the hang option of
% caption2.  natbib is used to do the citation using an
% author-year format. I've made an iitd.bst file that formats 
% the references as per the SGU guidelines.
%
% To use this class do the following:
%  \documentclass[options]{sguphdece} 
%
% Options:
%
%   PhD, MS, MTech or BTech -- generates the appropriate title page
%   and loads the report class.
%
%   synopsis -- Generates the title page for the synopsis.  This also
%   loads the article class instead of the report.
%  
% Example:
%
% \documentclass[PhD,synopsis]{sguphdece}
% \documentclass[MS]{sguphdece}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}

\ProvidesClass{sguphdece}%[Jan 2021 Class for ECE SGU Dissertations]

\newif\if@PhD
\newif\if@MS
\newif\if@MTech
\newif\if@BTech
\newif\if@Dual
\newif\if@Other
\newif\if@Synopsis

\DeclareOption{PhD}{\@PhDtrue}
\DeclareOption{MS}{\@MStrue}
\DeclareOption{MTech}{\@MTechtrue}
\DeclareOption{BTech}{\@BTechtrue}
\DeclareOption{Dual}{\@Dualtrue}
\DeclareOption{Other}{\@Othertrue}
\DeclareOption{synopsis}{\@Synopsistrue}
\ProcessOptions\relax

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Load the correct class.
\if@Synopsis
    \LoadClass[12pt,a4paper]{article}
\else
    \LoadClass[12pt,a4paper]{report}
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Geometry and page layout
\RequirePackage[a4paper,left=1.2in,right=1.2in,top=1in,bottom=1in,
                headsep=.4in]{geometry}[2002/07/08]
\parskip 12pt

\renewcommand{\@pnumwidth}{2.5em}
%\renewcommand{\@tocrmarg}{2.5em}
\RequirePackage{graphicx}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Using setspace to do the single/double spacing.  Setspace also
%% makes all tables and figures have single spacing automatically.
\RequirePackage{setspace} 
\RequirePackage{atbeginend} % used to redefine the list environs
\setstretch{1.5}

%\BeforeBegin{itemize}{\vspace*{-5ex}\begin{singlespace}} % drop by Bahadure
%\AfterEnd{itemize}{\end{singlespace}} % drop by Bahadure

%\BeforeBegin{enumerate}{\vspace*{-5ex}\begin{singlespace}}  % drop by Bahadure
%\AfterEnd{enumerate}{\end{singlespace}}  % drop by Bahadure

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% The figure captioning is done correctly via the hang option.
%%\RequirePackage[hang]{caption2}  -> TeX generates error
\RequirePackage[hang]{caption}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Bibliography
% 
% natbib allows easy switching of citation style and using it along
% with the iitd.bst makes things perfect.
% \RequirePackage[authoryear,round]{natbib} 
%\RequirePackage[numbers,square]{natbib} 
% \bibliographystyle{iitd}
%\bibliographystyle{alpha} % Drop by BAHADURE orgi=nal alpha % apacite
% \newcommand{\bibstyle@iitd}{\bibpunct{(}{)}{;}{a}{,}{,}%
    %  \gdef\NAT@biblabel##1{##1. }}
%
% \setlength{\bibhang}{0pt}
% \citestyle{sgu}
%\citestyle{unsrt_newen}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Other useful macros.  Many of these are modifications from newdiss.cls

% \department{department name} -- user macro to declare name of department.
\def\department#1{\gdef\@department{#1}}


\let\@advisor\relax
\def\advisor#1{\def\@advisor{#1}}

\let\@program\relax
\def\program#1{\def\@program{#1}}

\let\@entrynumber\relax
\def\entrynumber#1{\def\@entrynumber{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The title page

\def\maketitle{%
  \pagenumbering{roman}
  \thispagestyle{empty}
  \newpage
  \null
  \setcounter{page}{0}
  \parskip=0pt
  \begin{center}%
  \let \footnote \thanks
  \vglue 0in % this makes top margin 2in
  \vskip -5ex%
  \if@Synopsis
    {\large \em %SYNOPSIS OF 
\par}
  \fi
    {\Large \bf \expandafter{\@title} \par}%
    \vskip 10ex%
    {\normalsize
      \if@PhD
         {\em A Synopsis }\par
         \vskip 3ex%
         \if@Synopsis
            {\normalsize \em submitted by \par}
         \else
            {\normalsize \em submitted by \par}
         \fi
         {\bf \large{\@author}\par\par}
         {\bf {\@entrynumber}\par\par}
         \vskip 3ex%
         {\normalsize \em under the guidance of \par}
         \vskip 3ex%
         {\bf \large{Dr. Nilesh Bhaksrrao Bahadure\\ \& \\ Dr. P.D. Patil\@advisor}\par\par}
         \vskip 3ex%}
         {\normalsize \em for the award of the degree }\par
         \vskip 3ex%
         {\em of} \par
         \vskip 3ex%
         {\bf \large {Doctor of Philosophy}} \par
       \else
         \if@MS
            {\em A THESIS }\par
            \vskip 5ex%
            {\bf \large{\@author}\par\par}
            {\bf {\@entrynumber}\par\par}
            \vskip 5ex%
            {\normalsize \em under the guidance of}
            {\bf \large{\@advisor}\par\par}
            \vskip 3ex%}
            {\normalsize \em for the award of the degree }\par
            \vskip 3ex%
            {\em of} \par
            \vskip 3ex%
            {\bf \large {Master Of Science}} \par
            (by Research) \par
         \else
           {\em Thesis submitted by \par}
           \vskip 5ex%
           {\bf \large{\@author}\par\par}
           {\bf {\@entrynumber}\par\par}
           \vskip 5ex%
           {\normalsize \em under the guidance of\par}
           {\bf \large{\@advisor}\par}
           \vskip 5ex%}
           {\normalsize \em in partial fulfilment of the requirements\par
             for the award of the degree of \par}
           \vskip 5ex%
           \if@MTech
             {\bf Master of Technology}
           \fi
           \if@Dual
             {\bf Bachelor and Master of Technology}
           \fi
           \if@BTech
              {\bf Bachelor and Master of Technology}
           \fi
           \if@Other
              {\bf {\@program}}
           \fi
         \fi
      \fi
    }
  \end{center}%

  \centerline{\includegraphics[height=1.0in,width=1.0in, keepaspectratio]{SGU_Logo}}
  \vspace*{-0.15in}
  \begin{center}
    {\bf \large School of Technology \\ Department  of \@department\par}
    {\bf \large Sanjay Ghodawat University\\Kolhapur, Maharashtra, India}
    \vglue 0.50em
    {\bf \large \@date}\par
  \end{center}
  \parskip 8pt
}

\def\titlepage{\newpage\thispagestyle{empty}\c@page\z@}
\def\endtitlepage{\newpage}

\if@Synopsis
   \renewcommand\refname{REFERENCES}
\else
   % QUOTATIONS
   %
   \def\quotations{\chapter*{\centerline{QUOTATIONS}}
   %\addcontentsline{toc}{chapter}{QUOTATIONS}
   }

   % DEDICATION
   %
   \def\dedication{\chapter*{\centerline{DEDICATION}}
   %\addcontentsline{toc}{chapter}{DEDICATION}
   }

   % CERTIFICATE
   %
   %   - this produces a certificate page as per IITD Regulations
   %     comment the following lines out to get it working.
   %
   \def\certificate{%% A preliminary chapter
     \clearpage
     \vspace*{36pt}
     \centerline{\Large \bf THESIS CERTIFICATE}
     \vskip 25pt
     \thispagestyle{empty}
     \typeout{Certificate}
     \setcounter{page}{0}
   }

   % ACKNOWLEDGEMENTS
   %
   \def\acknowledgements{\chapter*{\centerline{ACKNOWLEDGEMENTS}}
     \addcontentsline{toc}{chapter}{ACKNOWLEDGEMENTS}
   }

   % ABSTRACT
   %   - this produces pages suitable for an IITD Abstract
   \def\abstract{\chapter*{\centerline{ABSTRACT}}
   \addcontentsline{toc}{chapter}{ABSTRACT}
   }

   % GLOSSARY
   %
   \def\glossary{\chapter*{\centerline{GLOSSARY}}
   \addcontentsline{toc}{chapter}{GLOSSARY}
   }

   % ABBREVIATIONS
   %
   \def\abbreviations{\chapter*{\centerline{ABBREVIATIONS}}
   \addcontentsline{toc}{chapter}{ABBREVIATIONS}
   }

   % Use the nomencl package for the NOTATION section.

   % Makes the chapter heading
   \def\@makechapterhead#1{%
     {\parindent \z@ \raggedright \normalfont
       \ifnum \c@secnumdepth >\m@ne
       \begin{center}
         \Large\bfseries \@chapapp\space \thechapter
       \end{center}
       \par\nobreak
       \vskip 20\p@
       \fi
       \interlinepenalty\@M
       \Large \bf
       \begin{center}
         #1\par\nobreak      
       \end{center}
       \vskip 20\p@
       \thispagestyle{empty}
     }}

   % Makes the chapter heading for \chapter* commands
   \def\@makeschapterhead#1{%
     \vspace*{25\p@}%
     {\parindent \z@ \raggedright
       \normalfont
       \interlinepenalty\@M
       \Large \bfseries #1\par\nobreak
       \vskip 20\p@
     }}


   %LIST OF PAPERS
   \def\listofpapers{
           \normalbaselines
           \chapter*{\centerline{LIST OF PAPERS BASED ON THESIS}}
           \markboth{LIST OF PAPERS BASED ON THESIS}{LIST OF PAPERS BASED ON THESIS}
           %\addcontentsline{toc}{chapter}{LIST OF PAPERS BASED ON THESIS}
   }

   
   % CV
   \def\CV{\chapter*{\centerline{CURRICULUM VITAE}}}

   % Comittee
   \if@PhD
       \def\committee{\chapter*{\centerline{DOCTORAL COMMITTEE}}}
   \else
       \if@MS
          \def\committee{\chapter*{\centerline{GENERAL TEST COMITTEE}}}}
        \fi
   \fi


   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % Renewed commands to set the titles of various pages correctly.
   \renewcommand\contentsname{\centering TABLE OF CONTENTS}
   \renewcommand\listfigurename{\centering LIST OF FIGURES}
   \renewcommand\listtablename{\centering LIST OF TABLES}
   \renewcommand{\chaptername}{CHAPTER}
   \renewcommand\bibname{\centering REFERENCES}
   \renewcommand\appendixname{APPENDIX}
\fi


